exceptiontools.InputSpecificationError
======================================

.. abjad-lineage:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError

.. autoclass:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InputSpecificationError.InputSpecificationError.__unicode__
   :noindex:
